==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticatorConfigEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapAuthenticatorConfigEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> entityFieldDelegate;
    public MapAuthenticatorConfigEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAlias() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ALIAS);
    }
    @SuppressWarnings("unchecked") @Override public void setAlias(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ALIAS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getConfig() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.CONFIG, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticatorConfigEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAuthenticatorConfigEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> entityFieldDelegate;
    public MapAuthenticatorConfigEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAlias() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ALIAS);
    }
    @SuppressWarnings("unchecked") @Override public void setAlias(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.ALIAS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getConfig() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticatorConfigEntityFields.CONFIG, p0);
    }
}
